import { HttpResponse as RawHttpResponse } from "ziron-ws";
export interface HttpResponse extends RawHttpResponse {
    headers: Record<string, string>;
    writeHeader: any;
    writeHeaders: (extraHeaders?: Record<string, string>) => HttpResponse;
    aborted?: boolean;
    ended?: boolean;
    writeFile: (path: string, reqHeaders?: {
        'if-modified-since'?: string;
        range?: string;
        'accept-encoding'?: string;
    }, handleLastModified?: boolean) => void;
    redirect: (location: string) => void;
}
export default function enhanceHttpResponse(res: RawHttpResponse & Partial<HttpResponse>): HttpResponse;
/**
 * @description
 * Write response headers utility function.
 * @param res
 * @param headers
 */
export declare function writeResponseHeaders(res: RawHttpResponse, headers?: {
    [name: string]: string;
}): void;
/**
 * @description
 * Redirects to another location.
 * @param res
 * @param location
 */
export declare function writeResponseRedirection(res: RawHttpResponse, location: string): void;
/**
 * @description
 * Streams a file in a response.
 * Also handles last modified.
 * @param res
 * @param path
 * @param reqHeaders
 * @param handleLastModified
 */
export declare function sendFileToRes(res: HttpResponse, path: string, reqHeaders?: {
    'if-modified-since'?: string;
    range?: string;
    'accept-encoding'?: string;
}, handleLastModified?: boolean): RawHttpResponse | undefined;
